### Line Generator

This is a simple string line generator based on templates for generating logs, testing your scripts and algorithms or other stuff if you need.

#### Status: in development

### Install

```pip install linegenerator```


### Requirements 
- Python >= 3.9
- click >= 8.0.0 


### License 
[MIT License](LICENSE)

#### TODO:
- [ ] Add Templates
- [ ] Add Faker
- [ ] Add changelog
- [ ] Add readthedocs
- [ ] Add dev mode config